==> xlniuxdata-vipgame-1.0.58-20160429.084505-3-sources.jar: com/xunlei/niux/data/vipgame/dto/MobileGuildSpreadDTO.java <==
package com.xunlei.niux.data.vipgame.dto;

import java.io.Serializable;

/**
 * Created by Dean on 2016/4/22.
 */
public class MobileGuildSpreadDTO implements Serializable{
    private Long seqId;
    private Long guildUserId;
    private String gameId;
    private String gameNo;
    private String appVersion;
    private String apkName;
    private String  appSize;
    private String  platform;
    private String	inputTime;
    private String	downloadUrl;
    private String gameName;

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public Long getGuildUserId() {
        return guildUserId;
    }

    public void setGuildUserId(Long guildUserId) {
        this.guildUserId = guildUserId;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getAppVersion() {
        return appVersion;
    }

    public void setAppVersion(String appVersion) {
        this.appVersion = appVersion;
    }

    public String getAppSize() {
        return appSize;
    }

    public void setAppSize(String appSize) {
        this.appSize = appSize;
    }

    public String getPlatform() {
        return platform;
    }

    public void setPlatform(String platform) {
        this.platform = platform;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getDownloadUrl() {
        return downloadUrl;
    }

    public void setDownloadUrl(String downloadUrl) {
        this.downloadUrl = downloadUrl;
    }

    public String getGameName() {
        return gameName;
    }

    public void setGameName(String gameName) {
        this.gameName = gameName;
    }

    public String getGameNo() {
        return gameNo;
    }

    public void setGameNo(String gameNo) {
        this.gameNo = gameNo;
    }

    public String getApkName() {
        return apkName;
    }

    public void setApkName(String apkName) {
        this.apkName = apkName;
    }
}

==> xlniuxdata-vipgame-1.0.60-20160516.090641-2-sources.jar: com/xunlei/niux/data/vipgame/dto/MobileGuildSpreadDTO.java <==
package com.xunlei.niux.data.vipgame.dto;

import java.io.Serializable;

/**
 * Created by Dean on 2016/4/22.
 */
public class MobileGuildSpreadDTO implements Serializable{
    private Long seqId;
    private Long guildUserId;
    private String gameId;
    private String gameNo;
    private String appVersion;
    private String apkName;
    private String  appSize;
    private String  platform;
    private String	inputTime;
    private String	downloadUrl;
    private String gameName;
    private String hasFinished;

    public Long getSeqId() {
        return seqId;
    }

    public void setSeqId(Long seqId) {
        this.seqId = seqId;
    }

    public Long getGuildUserId() {
        return guildUserId;
    }

    public void setGuildUserId(Long guildUserId) {
        this.guildUserId = guildUserId;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getAppVersion() {
        return appVersion;
    }

    public void setAppVersion(String appVersion) {
        this.appVersion = appVersion;
    }

    public String getAppSize() {
        return appSize;
    }

    public void setAppSize(String appSize) {
        this.appSize = appSize;
    }

    public String getPlatform() {
        return platform;
    }

    public void setPlatform(String platform) {
        this.platform = platform;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getDownloadUrl() {
        return downloadUrl;
    }

    public void setDownloadUrl(String downloadUrl) {
        this.downloadUrl = downloadUrl;
    }

    public String getGameName() {
        return gameName;
    }

    public void setGameName(String gameName) {
        this.gameName = gameName;
    }

    public String getGameNo() {
        return gameNo;
    }

    public void setGameNo(String gameNo) {
        this.gameNo = gameNo;
    }

    public String getApkName() {
        return apkName;
    }

    public void setApkName(String apkName) {
        this.apkName = apkName;
    }

    public String getHasFinished() {
        return hasFinished;
    }

    public void setHasFinished(String hasFinished) {
        this.hasFinished = hasFinished;
    }
}
